@@ -75,7 +75,7 @@ bcopy (from, to, len)
 #endif
 #endif
 
-char *version_string = "GNU sed version 2.02";
+char *version_string = "GNU sed version 2.03";
 
 /* Struct vector is used to describe a chunk of a compiled sed program.  
  * There is one vector for the main program, and one for each { } pair,
@@ -1104,13 +1104,15 @@ buffer_regex (slash)
 void
 compile_regex ()
 {
-  
+  const char * error;
   last_regex = ((struct re_pattern_buffer *)
 		ck_malloc (sizeof (struct re_pattern_buffer)));
   bzero (last_regex, sizeof (*last_regex));
   last_regex->fastmap = ck_malloc (256);
-  re_compile_pattern (last_regex_string,
-		      strlen (last_regex_string), last_regex);
+  error = re_compile_pattern (last_regex_string,
+			      strlen (last_regex_string), last_regex);
+  if (error)
+    bad_prog ((char *)error);
 }
 
 /* Store a label (or label reference) created by a ':', 'b', or 't'
